@@ -60,7 +60,7 @@ class PostgreSQLExecutor(TCPExecutor):
     )
 
     VERSION_RE = re.compile(r".* (?P<version>\d+\.\d+)")
-    MIN_SUPPORTED_VERSION = parse_version("9.6")
+    MIN_SUPPORTED_VERSION = parse_version("10")
 
     def __init__(
         self,
@@ -71,12 +71,12 @@ class PostgreSQLExecutor(TCPExecutor):
         unixsocketdir: str,
         logfile: str,
         startparams: str,
+        dbname: str,
         shell: bool = False,
         timeout: Optional[int] = 60,
         sleep: float = 0.1,
         user: str = "postgres",
         password: str = "",
-        dbname: Optional[str] = None,
         options: str = "",
         postgres_options: str = "",
     ):
